NAME
PPI::Token - A single token of Perl source code
INHERITANCE
PPI::Token
isa PPI::Element
DESCRIPTION
PPI::Token is the abstract base class for all Tokens. In PPI terms, a "Token" is a PPI::Element that directly represents bytes of source code.
METHODS
set_content $string
The set_content method allows to set/change the string that the PPI::Token object represents.
Returns the string you set the Token to
add_content $string
The add_content method allows you to add additional bytes of code to the end of the Token.
Returns the new full string after the bytes have been added.
length
The length method returns the length of the string in a Token.